@@ -6,6 +6,7 @@ from .capture import (
     ImageProvider,
 )
 from .cut import FixedCutProvider, NullCutProvider, UnscaledFixedCutProvider
+from .extract_text import BaseOCRRegion, ExtractTextProvider, TextRegionSettings
 from .eyes_base import EyesBase
 from .eyes_runner import EyesRunner
 from .feature import Feature
@@ -72,4 +73,7 @@ __all__ = (
     "VisualLocator",
     "VisualLocatorSettings",
     "Feature",
+    "TextRegionSettings",
+    "ExtractTextProvider",
+    "BaseOCRRegion",
 )
