@@ -5,7 +5,14 @@ import platform
 import typing
 import uuid
 
-from applitools.common import AppOutput, RectangleSize, Region, RunningSession, logger
+from applitools.common import (
+    AppOutput,
+    RectangleSize,
+    Region,
+    RunningSession,
+    deprecated,
+    logger,
+)
 from applitools.common.config import Configuration
 from applitools.common.errors import (
     DiffsFoundError,
@@ -32,13 +39,20 @@ from applitools.core.debug import (
 )
 from applitools.core.eyes_mixins import EyesConfigurationMixin
 
+from . import __version__
+from .extract_text import (
+    PATTERN_TEXT_REGIONS,
+    BaseOCRRegion,
+    ExtractTextProvider,
+    TextRegionSettings,
+)
 from .match_window_task import MatchWindowTask
 from .positioning import InvalidPositionProvider, PositionProvider, RegionProvider
 from .scaling import FixedScaleProvider, NullScaleProvider, ScaleProvider
 from .server_connector import ServerConnector
 
 if typing.TYPE_CHECKING:
-    from typing import Optional, Text, Union
+    from typing import List, Optional, Text, Union
 
     from applitools.common import MatchLevel
     from applitools.common.capture import EyesScreenshot
@@ -147,8 +161,29 @@ class DebugScreenshotsAbstract(ABC):
         pass
 
 
+class ExtractTextMixin(object):
+    _extract_text_provider = None  # type: Optional[ExtractTextProvider]
+
+    def extract_text(self, *regions):
+        # type: (*BaseOCRRegion) -> List[Text]
+        argument_guard.not_none(self._extract_text_provider)
+        logger.info("extract_text", regions=regions)
+        return self._extract_text_provider.get_text(*regions)
+
+    def extract_text_regions(self, config):
+        # type: (TextRegionSettings) -> PATTERN_TEXT_REGIONS
+        argument_guard.not_none(self._extract_text_provider)
+        argument_guard.is_a(config, TextRegionSettings)
+        logger.info("extract_text_regions", config=config)
+        return self._extract_text_provider.get_text_regions(config)
+
+
 class EyesBase(
-    EyesConfigurationMixin, DebugScreenshotsAbstract, _EyesBaseAbstract, ABC
+    EyesConfigurationMixin,
+    DebugScreenshotsAbstract,
+    _EyesBaseAbstract,
+    ExtractTextMixin,
+    ABC,
 ):
     _MAX_ITERATIONS = 10
     _running_session = None  # type: Optional[RunningSession]
@@ -161,6 +196,7 @@ class EyesBase(
     _should_match_once_on_timeout = False  # type: bool
     _is_opened = False  # type: bool
     _render_info = None  # type: Optional[RenderingInfo]
+    _app_output_provider = None  # type: Optional[AppOutputProvider]
     _render = False
     _cut_provider = None
     _should_get_title = False  # type: bool
@@ -464,8 +500,8 @@ class EyesBase(
             finally:
                 self._running_session = None
 
+    @deprecated.attribute("use `abort()` instead")
     def abort_if_not_closed(self):
-        logger.deprecation("Use `abort()` instead")
         self.abort()
 
     def open_base(
@@ -575,7 +611,8 @@ class EyesBase(
 
     def _log_open_base(self):
         logger.info(
-            "Running on: {} {} {}".format(
+            "Applitools SDK {}, running on: {} {} {}".format(
+                __version__,
                 platform.platform(),
                 platform.python_implementation(),
                 platform.python_version(),
@@ -644,13 +681,15 @@ class EyesBase(
         logger.debug("No running session, calling start session...")
         self._start_session()
 
-        output_provider = AppOutputProvider(self._get_app_output_with_screenshot)
+        self._app_output_provider = AppOutputProvider(
+            self._get_app_output_with_screenshot
+        )
         self._match_window_task = MatchWindowTask(
             self._server_connector,
             self._running_session,
             self.configure.match_timeout,
             eyes=self,
-            app_output_provider=output_provider,
+            app_output_provider=self._app_output_provider,
         )
 
     def _get_app_output_with_screenshot(self, region, last_screenshot, check_settings):
