@@ -13,6 +13,7 @@ if typing.TYPE_CHECKING:
     from typing import List, Optional, Union
 
     from applitools.common.capture import EyesScreenshot
+    from applitools.common.utils.custom_types import CodedRegionPadding
     from applitools.core.eyes_base import EyesBase
 
 __all__ = (
@@ -31,6 +32,11 @@ class GetRegion(ABC):
         # type: (EyesBase, EyesScreenshot) -> List
         pass
 
+    @property
+    def padding(self):
+        # type: () -> Optional[CodedRegionPadding]
+        return getattr(self, "_padding", None)
+
 
 class GetFloatingRegion(GetRegion, ABC):
     @property
