@@ -2,7 +2,6 @@ from __future__ import absolute_import
 
 import itertools
 import json
-import math
 import typing
 import uuid
 from threading import Condition
@@ -14,6 +13,7 @@ from requests import Response
 from requests.packages import urllib3  # noqa
 
 from applitools.common import Region, RunningSession, logger
+from applitools.common.client_event import LogSessionsClientEvents
 from applitools.common.errors import EyesError, EyesServiceUnavailableError
 from applitools.common.match import MatchResult
 from applitools.common.match_window_data import MatchWindowData
@@ -36,13 +36,18 @@ from applitools.common.utils import (
     urljoin,
 )
 from applitools.common.utils.compat import raise_from
+from applitools.core.extract_text import (
+    PATTERN_TEXT_REGIONS,
+    TextRegion,
+    TextSettingsData,
+)
 from applitools.core.locators import LOCATORS_TYPE, VisualLocatorsData
 
 if typing.TYPE_CHECKING:
     from typing import Any, Dict, List, Optional, Text, Union
     from uuid import UUID
 
-    from applitools.common.logger import ClientEvent
+    from applitools.common.client_event import ClientEvent
 
 # Prints out all data sent/received through 'requests'
 # import httplib
@@ -68,6 +73,15 @@ def retry(
     return datetime_utils.retry(delays, exception, report)
 
 
+def delays_gen(delay, repeat, factor, max):
+    while delay < max:
+        for _ in range(repeat):
+            yield delay
+        delay *= factor
+    while True:
+        yield max
+
+
 @attr.s
 class ClientSession(object):
     """ A proxy to requests.Session """
@@ -132,10 +146,6 @@ class ClientSession(object):
 
 @attr.s
 class _RequestCommunicator(object):
-    LONG_REQUEST_DELAY_MS = 2000  # type: int
-    MAX_LONG_REQUEST_DELAY_MS = 10000  # type: int
-    LONG_REQUEST_DELAY_MULTIPLICATIVE_INCREASE_FACTOR = 1.5  # type: float
-
     headers = attr.ib()  # type: Dict
     timeout_ms = attr.ib(default=None)  # type: int
     api_key = attr.ib(default=None)  # type: Text
@@ -187,6 +197,7 @@ class _RequestCommunicator(object):
         # type: (Text, Text, **Any) -> Response
         headers = kwargs.get("headers", self.headers).copy()
         headers["Eyes-Expect"] = "202+location"
+        headers["Eyes-Expect-Version"] = "2"
         headers["Eyes-Date"] = datetime_utils.current_time_in_rfc1123()
         kwargs["headers"] = headers
         request_id = uuid.uuid4()
@@ -225,27 +236,27 @@ class _RequestCommunicator(object):
         else:
             raise EyesError("Unknown error during long request: {}".format(response))
 
-    def _long_request_loop(self, url, request_id, delay=LONG_REQUEST_DELAY_MS):
-        delay = min(
-            self.MAX_LONG_REQUEST_DELAY_MS,
-            math.floor(delay * self.LONG_REQUEST_DELAY_MULTIPLICATIVE_INCREASE_FACTOR),
-        )
-        logger.debug(
-            "Long request {}. Still running... Retrying in {} ms".format(
-                request_id, delay
+    def _long_request_loop(self, url, request_id):
+        delays = delays_gen(500, 5, 2, 5000)
+        delay = next(delays)
+        while True:
+            datetime_utils.sleep(
+                delay, "Long request {} still running".format(request_id)
             )
-        )
-
-        datetime_utils.sleep(delay)
-        response = self.request(
-            "get",
-            url,
-            request_id=request_id,
-            headers={"Eyes-Date": datetime_utils.current_time_in_rfc1123()},
-        )
-        if response.status_code != requests.codes.ok:
-            return response
-        return self._long_request_loop(url, request_id, delay)
+            response = self.request(
+                "get",
+                url,
+                request_id=request_id,
+                headers={"Eyes-Date": datetime_utils.current_time_in_rfc1123()},
+            )
+            if response.status_code == requests.codes.ok:
+                url = response.headers.get("Location", url)
+                if "Retry-After" in response.headers:
+                    delay = int(response.headers["Retry-After"]) * 1000
+                else:
+                    delay = next(delays)
+            else:
+                return response
 
 
 class _SessionRetryLimiter(object):
@@ -292,7 +303,7 @@ class ServerConnector(object):
         "x-applitools-eyes-client": None,
     }
 
-    API_SESSIONS = "api/sessions"
+    API_SESSIONS = "/api/sessions"
     API_SESSIONS_LOG = "/api/sessions/log"
     API_SESSIONS_BATCHES = "/api/sessions/batches"
     API_SESSIONS_RUNNING = API_SESSIONS + "/running/"
@@ -317,7 +328,7 @@ class ServerConnector(object):
         :param client_session: session for communication with server.
         """
         self._render_info = None  # type: Optional[RenderingInfo]
-        self._ua_string = None  # type: Optional[RenderingInfo]
+        self._ua_string = None  # type: Optional[Text]
 
         if client_session:
             self._com = _RequestCommunicator(
@@ -598,7 +609,7 @@ class ServerConnector(object):
 
     @retry()
     def render_put_resource(self, resource):
-        # type: (Text, VGResource) -> Text
+        # type: (VGResource) -> Text
         argument_guard.not_none(resource)
         if self._render_info is None:
             raise EyesError("render_info must be fetched first")
@@ -630,7 +641,6 @@ class ServerConnector(object):
             )
         return resource.hash
 
-    @retry()
     def download_resource(self, url):
         # type: (Text) -> Response
         headers = {
@@ -642,18 +652,21 @@ class ServerConnector(object):
         logger.debug("Fetching URL {}\nwith headers {}".format(url, headers))
         timeout_sec = datetime_utils.to_sec(self._com.timeout_ms)
         try:
-            response = requests.get(
-                url, headers=headers, timeout=timeout_sec, verify=False
-            )
-            if response.status_code == requests.codes.not_acceptable:
-                response = requests.get(url, timeout=timeout_sec, verify=False)
-            return response
-        except (requests.HTTPError, requests.ConnectionError):
+            return self._try_download_resources(headers, timeout_sec, url)
+        except (requests.HTTPError, requests.ConnectionError) as e:
+            logger.warning("Failed to download resource", url=url, exc=e)
             response = Response()
             response._content = b""
             response.status_code = requests.codes.no_response
             return response
 
+    @retry()
+    def _try_download_resources(self, headers, timeout_sec, url):
+        response = requests.get(url, headers=headers, timeout=timeout_sec, verify=False)
+        if response.status_code == requests.codes.not_acceptable:
+            response = requests.get(url, timeout=timeout_sec, verify=False)
+        return response
+
     @retry()
     def render_status_by_id(self, *render_ids):
         # type: (*Text) -> List[RenderStatusResults]
@@ -722,7 +735,7 @@ class ServerConnector(object):
         # type: (*ClientEvent) -> None
         # try once
         try:
-            events = json_utils.to_json(logger.LogSessionsClientEvents(client_events))
+            events = json_utils.to_json(LogSessionsClientEvents(client_events))
             self._com.request("post", self.API_SESSIONS_LOG, data=events)
         except Exception:
             logger.exception("send_logs failed")
@@ -741,3 +754,48 @@ class ServerConnector(object):
             ),
             params={"AccessToken": test_results.secret_token},
         ).raise_for_status()
+
+    def get_text_in_running_session_image(self, data):
+        # type: (TextSettingsData) -> List[Text]
+        logger.debug(
+            "call",
+            _class=self.__class__.__name__,
+            _method="extract_text",
+            text_region_data=data,
+        )
+        resp = self._com.long_request(
+            "post",
+            urljoin(self.API_SESSIONS_RUNNING, "images/text"),
+            data=json_utils.to_json(data),
+        )
+        if resp.ok:
+            return resp.json()
+        raise EyesError(
+            "ServerConnector.extract_text - unexpected status {}".format(
+                resp.status_code
+            )
+        )
+
+    def get_text_regions_in_running_session_image(self, data):
+        # type: (TextSettingsData) -> PATTERN_TEXT_REGIONS
+        logger.debug(
+            "call",
+            _class=self.__class__.__name__,
+            _method="extract_text_regions",
+            text_region_data=data,
+        )
+        resp = self._com.long_request(
+            "post",
+            urljoin(self.API_SESSIONS_RUNNING, "images/textregions"),
+            data=json_utils.to_json(data),
+        )
+        if resp.ok:
+            return {
+                pattern: json_utils.attr_from_dict(regions, TextRegion)
+                for pattern, regions in iteritems(resp.json())
+            }
+        raise EyesError(
+            "ServerConnector.extract_text_regions - unexpected status {}".format(
+                resp.status_code
+            )
+        )
